<!DOCTYPE gui >
<gui name="kleopatra" version="502" >
    <MenuBar>
        <Menu name="file">
            <text>&amp;File</text>
            <Action name="file_new_certificate"/>
            <Separator/>
            <Action name="file_lookup_certificates"/>
            <Action name="file_import_certificates"/>
            <Separator/>
            <Action name="file_export_certificates"/>
            <Action name="file_export_secret_keys"/>
            <Action name="file_export_paper_key"/>
            <Action name="file_export_certificates_to_server"/>
            <Separator/>
            <Action name="file_decrypt_verify_files"/>
            <Action name="file_sign_encrypt_files"/>
            <Action name="file_sign_encrypt_folder"/>
            <Separator/>
            <Action name="file_checksum_create_files"/>
            <Action name="file_checksum_verify_files"/>
            <Separator/>
            <Action name="quit" />
        </Menu>
        <Menu name="view">
            <text>&amp;View</text>
            <Action name="view_redisplay"/>
            <Separator/>
            <Action name="view_stop_operations"/>
            <Action name="view_certificate_details"/>
            <Separator/>
            <Action name="window_view_hierarchical"/>
            <Separator/>
            <Action name="window_expand_all"/>
            <Action name="window_collapse_all"/>
            <Separator/>
            <Action name="pad_view"/>
        </Menu>
        <Menu name="certMenu">
            <text>&amp;Certificates</text>
            <Action name="certificates_change_owner_trust"/>
            <Action name="certificates_trust_root"/>
            <Action name="certificates_distrust_root"/>
            <Separator/>
            <Action name="certificates_certify_certificate"/>
            <Action name="certificates_change_expiry"/>
            <Action name="certificates_change_passphrase"/>
            <Action name="certificates_add_userid"/>
            <Separator/>
            <Action name="certificates_delete"/>
        </Menu>
        <Menu name="tools">
            <text>&amp;Tools</text>
            <Action name="tools_start_kwatchgnupg"/>
            <Separator/>
            <Action name="tools_refresh_x509_certificates"/>
            <Action name="tools_refresh_openpgp_certificates"/>
            <Separator/>
            <Action name="manage_smartcard"/>
            <Separator/>
            <Action name="clipboard_menu"/>
            <Separator/>
            <Action name="crl_import_crl"/>
            <Separator/>
            <Action name="crl_clear_crl_cache"/>
            <Action name="crl_dump_crl_cache"/>
            <Separator/>
            <Action name="configure_backend"/>
        </Menu>
        <Menu name="settings">
            <text>&amp;Settings</text>
            <Action name="settings_self_test"/>
        </Menu>
        <Menu name="window" append="settings_merge">
            <text>&amp;Window</text>
            <Action name="window_rename_tab"/>
            <Separator/>
            <Action name="window_new_tab"/>
            <Action name="window_duplicate_tab"/>
            <Action name="window_close_tab"/>
            <Separator/>
            <Action name="window_move_tab_left"/>
            <Action name="window_move_tab_right"/>
        </Menu>
        <Menu name="help">
            <text>&amp;Help</text>
            <Action name="help_show_compendium"/>
            <Action name="help_check_updates"/>
        </Menu>
    </MenuBar>

    <ToolBar fullWidth="false" name="mainToolBar" iconText="TextUnderIcon">
        <text>Main Toolbar</text>
        <Action name="file_sign_encrypt_files"/>
        <Action name="file_decrypt_verify_files"/>
        <Separator/>
        <Action name="file_import_certificates"/>
        <Action name="file_export_certificates"/>
        <Action name="certificates_certify_certificate"/>
        <Action name="file_lookup_certificates"/>
        <Separator/>
        <Action name="pad_view"/>
        <Separator/>
    </ToolBar>

    <Menu name="listview_popup">
        <text>&amp;Certificates</text>
        <Action name="certificates_certify_certificate"/>
        <Action name="certificates_trust_root"/>
        <Action name="certificates_distrust_root"/>
        <Action name="certificates_change_owner_trust"/>
        <Separator/>
        <Action name="certificates_change_expiry"/>
        <Action name="certificates_change_passphrase"/>
        <Action name="certificates_add_userid"/>
        <Separator/>
        <Action name="certificates_delete"/>
        <Separator/>
        <Action name="file_export_certificates"/>
        <Action name="file_export_secret_keys"/>
        <Action name="file_export_paper_key"/>
        <Action name="file_export_certificates_to_server"/>
        <Separator/>
        <Action name="view_certificate_details"/>
    </Menu>

</gui>
