<?xml version='1.0'?>
<!DOCTYPE gui SYSTEM 'kpartgui.dtd'>
<gui version="417" name="kontact">
 <MenuBar>
  <Menu noMerge="1" name="file">
   <text>&amp;File</text>
   <Merge/>
   <Separator/>
   <Action name="file_quit"/>
   <Merge/>
  </Menu>
  <Merge/>
  <Menu noMerge="1" name="view">
   <text>&amp;View</text>
   <Action name="hide_show_sidebar"/>
  </Menu>
  <Menu noMerge="1" name="settings">
   <text>&amp;Settings</text>
   <Merge name="StandardToolBarMenuHandler"/>
   <Merge/>
   <Action name="options_configure_keybinding"/>
   <Action name="options_configure_toolbars"/>
   <DefineGroup name="settings_configure"/>
   <Action name="settings_configure_kontact"/>
  </Menu>
  <Menu name="help">
   <text>&amp;Help</text>
   <Action name="help_introduction" append="help_whats_this_merge"/>
  </Menu>
 </MenuBar>
 <ToolBar noMerge="1" position="Top" name="navigatorToolBar" hidden="true">
  <text>Navigator</text>
  <ActionList name="navigator_actionlist"/>
 </ToolBar>
 <ToolBar noMerge="1" position="Top" name="mainToolBar">
  <text>Main Toolbar</text>
  <Action name="action_new"/>
  <Action name="action_sync"/>
  <Merge/>
 </ToolBar>
 <Merge/>
 <ActionProperties/>
</gui>
