<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<!--
  SPDX-FileCopyrightText: none
  SPDX-License-Identifier: BSD-3-Clause
-->
<gui name="PimDataExporter" version="9">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Action name="pimdataexporter_file_open_recent"/>
    <Separator/>
    <Action name="backup"/>
    <Action name="restore"/>
    <Separator/>
    <Action name="save_log"/>
    <Separator/>
    <Action name="show_structure_info"/>
    <Separator/>
    <Action name="file_quit"/>
  </Menu>
  <Menu noMerge="1" name="tools">
   <text>&amp;Tools</text>
   <Action name="show_archive_info"/>
   <Separator/>
   <Action name="show_current_archive_info"/>
  </Menu>
</MenuBar>
<ToolBar noMerge="1" name="mainToolBar" fullWidth="true" >
  <text>Main Toolbar</text>
  <Action name="backup" />
  <Action name="restore" />
</ToolBar>
</gui>
